==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/ActivitymimeattachmentCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Activitymimeattachment;
import microsoft.dynamics.crm.entity.request.ActivitymimeattachmentRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class ActivitymimeattachmentCollectionRequest extends CollectionPageEntityRequest<Activitymimeattachment, ActivitymimeattachmentRequest>{

    protected ContextPath contextPath;

    public ActivitymimeattachmentCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Activitymimeattachment.class, cp -> new ActivitymimeattachmentRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest activityMimeAttachment_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("ActivityMimeAttachment_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest activityMimeAttachment_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("ActivityMimeAttachment_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest activityMimeAttachment_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("ActivityMimeAttachment_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest activityMimeAttachment_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("ActivityMimeAttachment_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest activityMimeAttachment_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("ActivityMimeAttachment_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest activityMimeAttachment_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("ActivityMimeAttachment_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/ActivitymimeattachmentCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Activitymimeattachment;
import microsoft.dynamics.crm.entity.request.ActivitymimeattachmentRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class ActivitymimeattachmentCollectionRequest extends CollectionPageEntityRequest<Activitymimeattachment, ActivitymimeattachmentRequest>{

    protected ContextPath contextPath;

    public ActivitymimeattachmentCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Activitymimeattachment.class, cp -> new ActivitymimeattachmentRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest activityMimeAttachment_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("ActivityMimeAttachment_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest activityMimeAttachment_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("ActivityMimeAttachment_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest activityMimeAttachment_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("ActivityMimeAttachment_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest activityMimeAttachment_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("ActivityMimeAttachment_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest activityMimeAttachment_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("ActivityMimeAttachment_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest activityMimeAttachment_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("ActivityMimeAttachment_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

}
